@@ -19,8 +19,6 @@ import numpy as np
 
 from LIA import extract_features
 
-from pyspark.sql.types import StructType, StructField, StringType, DoubleType
-
 LIA_FEATURE_NAMES = ['f{}_{}'.format(j, i) for i in ['g', 'r'] for j in range(47)]
 
 def _extract(mag, magerr):
@@ -43,25 +41,6 @@ def _extract(mag, magerr):
 
     return out
 
-def load_mulens_schema_twobands():
-    """ DataFrame Schema for the mulens UDF using 2 filter bands
-
-    Returns
-    --------
-    schema: StructType
-        StructType with StructFields describing new columns to be added
-        when using `mulens` in pyspark UDF. There are 2 new columns per
-        filter bands: the classification name (str) and
-        the mulens score (double).
-    """
-    schema = StructType([
-        StructField("class_1", StringType(), True),
-        StructField("ml_score_1", DoubleType(), True),
-        StructField("class_2", StringType(), True),
-        StructField("ml_score_2", DoubleType(), True)
-    ])
-    return schema
-
 def load_external_model(model_path):
     """ Unpickle pre-loaded models from LIA.
 
